@@ -30,8 +30,10 @@ public slots:
     void playNext();
     void putb(int p,qint64,qint64);
     void abortDownload();
+    void back();
 private slots:
     void markComplete();
+    void updatePlayPosition(qint64 time);
 private:
     QNetworkAccessManager *manager;
     Phonon::AudioOutput *audioOutput;
@@ -44,5 +46,6 @@ private:
     QTime startStreamT;
     grooveProgressBar *pd;
     playlist *pl;
+
 };
 #endif // SPLAYER_H
